#!/usr/bin/env Rscript

### MERGE canada DATA
rm(list = ls())
source("R/format.data/format.fun.R")
library(reshape)
dir.create("output/formatted/Canada", recursive=TRUE,showWarnings=FALSE)


######################### READ DATA read individuals tree data
data.canada <- read.csv("data/raw/Canada/Canada_Data2George_20130910.csv", 
    header = TRUE, stringsAsFactors = FALSE)

#MCV remove plots smaller than 0.02 ha (plot size with average of <20 trees 10cm dbh)
#MCV and remove trees <10 cm dbh
data.canada <- subset(data.canada,subset=(data.canada$SubPlotSize>=0.02 & data.canada$InitDBH>=10) )

sum(is.na(data.canada$species))
data.canada$sp = data.canada$species_FIACode
data.canada$sp[data.canada.sp==8349] <- 762 #MCV replace incorrect sp code for Prunus serotina
data.canada$species_FIACode <- NULL
### read species names and merge with data.canada
species.clean <- read.csv("data/raw/Canada/FIA_REF_SPECIES.csv", stringsAsFactors = FALSE)
species.clean$Latin_name <- paste(species.clean$GENUS,species.clean$SPECIES, sep=" ")
species.clean$Latin_name_syn<- paste(species.clean$GENUS,species.clean$SPECIES, sep=" ")
data.canada <- merge(data.canada, data.frame(sp = species.clean$SPCD, Latin_name=species.clean[,"Latin_name"], stringsAsFactors = F), by = "sp", all.x = T)
data.canada$sp.name <- data.canada$Latin_name; data.canada$Latin_name<- NULL

data.canada$sp <-  paste("sp",data.canada$sp,sep=".")
######### MASSAGE TRAIT DATA HEIGHT DATA FOR TREE MISSING BRING US DATA FOR HEIGHT OVER
######### WHEN WE ANALYZE THAT DATASET LATER ON
######### FORMAT INDIVIDUAL TREE DATA
data.canada$FinalDBH[data.canada$FinalDBH < 0] <- NA 
data.canada$G <- 10 * (data.canada$FinalDBH - data.canada$InitDBH)/data.canada$Interval  ## diameter growth in mm per year
data.canada$G[which(data.canada$InitDBH == 0 | data.canada$FinalDBH == -999)] <- NA
data.canada$year <- data.canada$Interval; data.canada$IntervalYears <- NULL ## number of year between measurement
data.canada$D <- data.canada[["InitDBH"]]
data.canada$D[data.canada$D == 0] <- NA ## diameter in cm
data.canada$dead <- as.numeric(is.na(data.canada$FinalDBH))  ## dummy variable for dead tree 0 alive 1 dead
data.canada$htot <- rep(NA, nrow(data.canada))  ## height of tree in m
data.canada$plot <- data.canada$PlotID_InitYear ## plot id
data.canada$plot[!is.na(data.canada$SUBPLOT_ID)] <- paste(data.canada$plot[!is.na(data.canada$SUBPLOT_ID)],
                                                          data.canada$SUBPLOT_ID[!is.na(data.canada$SUBPLOT_ID)],sep=".") ## when subplot include it
data.canada$cluster <-rep(NA,nrow(data.canada))  ## cluster code
data.canada$cluster[!is.na(data.canada$SUBPLOT_ID)] <- data.canada$PlotID_InitYear[!is.na(data.canada$SUBPLOT_ID)]## when subplot use plot as cluster
data.canada$tree.id <- data.canada[["PlotTree_ID"]]; data.canada[["PlotTree_ID"]] <- NULL ## tree unique id
data.canada$census <- rep(1,nrow(data.canada))
data.canada$obs.id <- data.canada$tree.id
data.canada$weights <- 1/(data.canada$SubPlotSize*10000) ### there is some strange small value in SubPlotSize 20 m^2 even for large tree NEED TO ASK Hongcheng ## REPLY BETTER TO DElETE THIS PLOTS HE DON T KNOW WHY SO SMALLL
###################### ECOREGION merge to have no ecoregion with low number of observation
greco <- read.csv(file = "data/raw/Canada/EcoregionCodes.csv", header = T, 
    sep = "\t")
data.canada$ecocode <- data.canada$Ecocode; data.canada$Ecocode <- NULL
table(data.canada$ecocode)
## Some ecoregions still have small # of individuals, so either drop off for
## analysis later on or wait for Quebec data to come in 
## library(RColorBrewer)
## library(rworldmap)
## newmap <- getMap(resolution = 'coarse')
## # different resolutions available
## x11()
## plot(newmap,xlim=c(-110,-50),ylim=c(50,55))

## ecoreg <- factor(data.canada$ecocode); levels(ecoreg) <- mycols <- brewer.pal(length(levels(ecoreg)), "Set1")
## points(data.canada[['Lon']],data.canada[['Lat']],pty='.',cex=.2,col = as.character(ecoreg))
## legend('bottomleft', col = mycols, legend = names(table(data.canada$ecocode)), pch = rep(19,length(levels(ecoreg)))) 
## points(data.canada[['Lon']][data.canada$ecocode == "-331"], data.canada[['Lat']][data.canada$ecocode == "-331"],pty=2,cex=1, col = 'black') 
## points(data.canada[['Lon']][data.canada$ecocode == "-251"], data.canada[['Lat']][data.canada$ecocode == "-251"],pty=2,cex=1, col = 'red')

### delete the tree in this two ecoregion
data.canada <- subset(data.canada,subset=(data.canada$ecocode != "-251") & (data.canada$ecocode != "-331"))

#data.canada$eco_codemerged <- combine_factor(data.canada$eco_code,c(1:8,6,9))
###################### PERCENT DEAD variable percent dead/cannot do with since dead variable is
###################### missing compute numer of dead per plot to remove plot with disturbance
perc.dead <- tapply(data.canada[["dead"]], INDEX = data.canada[["plot"]], FUN = function.perc.dead2)
data.canada <- merge(data.canada, data.frame(plot = names(perc.dead), perc.dead = perc.dead), 
    by = "plot", sort = FALSE)
####################################### PLOT SELECTION FOR THE ANALYSIS Remove data with dead == 1
table(data.canada$dead)
## data.canada <- data.canada[data.canada$dead == 0,]
vec.abio.var.names <- c("MAT", "MAP")
vec.basic.var <- c("obs.id","tree.id", "sp", "sp.name","cluster","plot", "ecocode", "D", "G", "dead", 
    "year", "htot", "Lon", "Lat", "perc.dead","weights","census")
data.tree <- subset(data.canada, select = c(vec.basic.var, vec.abio.var.names))
write.csv(data.tree,file="output/formatted/Canada/tree.csv",row.names = FALSE)


