
###################################################
###################################################
###################################################
##### FUNCTION TO FORMAT DATA FOR THE WORKSHOP 
#### G. Kunstler 11/09/2013
source("R/packages.R")
check_packages(c("reshape", "boot","RColorBrewer","sp","dismo","rgdal","foreign","rworldmap"))

############################
## FUNCTION remove trailing white space
trim.trailing <- function (x) sub("\\s+$", "", x)


#############################################
## FUN to clean species name for FRENCH NFI
fun.clean.species.tab <- function(species.tab){
species.tab2 <- species.tab[!is.na(species.tab$Latin_name),]
### species IFN reformat names
## clean species names and synonyme names
species.tab2$Latin_name <- (gsub("_", " ", species.tab2$Latin_name))
species.tab2$Latin_name_syn<- (gsub("_", " ", species.tab2$Latin_name_syn))
## remove trailing white space
species.tab2$Latin_name_syn<- trim.trailing(species.tab2$Latin_name_syn)
species.clean <- species.tab2[!duplicated(species.tab2$Latin_name),
                              c("code","Latin_name","Exotic_Native_cultivated")]
names(species.clean) <- c("sp","Latin_name","Exotic_Native_cultivated")
return(species.clean)
}



#####################################################
### compute quantile 99% and sd with a bootstrap
##' ..  compute quantile 99% and sd with a bootstra..
##'
##' .. content for \details{} ..
##' @title f.quantile.boot
##' @param i subset (species) for which to compute quantile
##' @param x vector of height
##' @param fac vector of subset
##' @param R number of resampling
##' @param probs probability of quantile to compute
##' @return a matrix with # col and 1 row with mean sd adn nobs
##' @author Kunstler
f.quantile.boot <-  function(i,x,fac,R,probs=0.99){
require(boot)
 if(length(na.exclude(x[fac==i]))>0){
     quant.boot <- boot(x[fac==i],f.quantile,R=R,probs=probs)
     return(as.matrix(c(mean=mean(quant.boot$t),sd=sd(quant.boot$t),nobs=length(na.exclude(x[fac==i]))),ncol=3,nrow=1))
 }else{
     return(as.matrix(c(mean=NA,sd=NA,nobs=NA),ncol=3,nrow=1))
 }
}

f.quantile <- function (x,ind,probs){
    require(boot)
    quantile(x[ind],probs=probs,na.rm=TRUE)
}

#######################
### function to compute number of dead per plot 
function.perc.dead <-  function(dead){
 sum(dead)/length(dead)}

## function to deal with missing value
function.perc.dead2 <- function(dead) {
    out <- sum(dead,na.rm=T)/length(dead[!is.na(dead)])
    if(!is.finite(out)) out <- NA
    return(out)
}




######
######
## FUNCTION TO PLOT MAP OF TREE with function of DBH
##' .. Function to plot map of tree with circle function of their dbh..
##'
##' .. content for \details{} ..
##' @title 
##' @param plot.select the plot for which draw the map
##' @param x 
##' @param y 
##' @param plot vectore of plot id for each tree
##' @param D diameter in cm
##' @param inches controling the circle size
##' @param fg.l color circle
##' @param ... 
##' @return 
##' @author Kunstler
fun.circles.plot <- function(plot.select,x,y,plot,D,inches,fg.l,...){
x.t <- x[plot==plot.select]
y.t <- y[plot==plot.select]
D.t <- D[plot==plot.select]
fg <- fg.l[plot==plot.select]
D.t[is.na(D.t)] <-  0
symbols(x.t,y.t,circles=D.t ,main=plot.select,inches=inches,fg=fg,...)
}


